/*
 * DefaultSwingDropTarget.java
 * Part of the B'am library - a collection of general-purpose utility classes.
 * 
 * Copyright (C)2005-2008 Stephen Battey
 * Contact: resource@lucidviews.net
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

package net.lucidviews.util.gui.swing.dnd;

import javax.swing.TransferHandler;
import javax.swing.JComponent;
import java.awt.datatransfer.DataFlavor;
import java.awt.Component;


/**
 * An extension of the <code>DropTarget</code> class for Swing components that
 * invokes state changes on the drag'n'drop event.
 * <br />
 * <br />
 * This class must be sub-classed and the drag/drop methods overridden with
 * custom implementations. NB: overridden methods must call the super method
 * to invoke the state change on the event.
 * <br />
 * <br />
 * @author Stephen Battey
 * @version $Revision: 1.1.2.1 $
 * @since 1.3
 */
public class DefaultSwingDropTarget extends DefaultDropTarget
{
	
	/*
	 * Local constants
	 */
	
	/** Serialisation version id. */
	private static final long serialVersionUID = 793459131256841519L;
	
	
	/*
	 * Instance variables
	 */
	
	/** The component that is the target of dropped content. */
	protected JComponent target;
	
	
	/*
	 * Constructors
	 */
	
	/**
	 * Create a drop target for the specified Swing component.
	 * <br />
	 * <br />
	 * @param component the GUI component that is to accept DnDs
	 * @param supportedActions the actions that will be supported - a bit mask of DnDConstants
	 */
	protected DefaultSwingDropTarget( JComponent component, int supportedActions )
	{
		super( component, supportedActions );
		
		this.target = component;
	}
	
	
	/*
	 * Overridden methods of DefaultDropTarget
	 */
	
	/** {@inheritDoc} */
	protected boolean dataFlavourSupported( Component component, DataFlavor[] flavours )
	{
		try
		{
			JComponent swingComponent = (JComponent)component;
			TransferHandler importer = swingComponent.getTransferHandler();
			
			return (   (importer != null)
			        && (importer.canImport( swingComponent, flavours ))  );
		}
		catch (Throwable e)
		{
			// if we can't check the flavour, assume we can't support it
			return false;
		}
	}
	
}


/*
 * Change History
 *
 * $Log: DefaultSwingDropTarget.java,v $
 * Revision 1.1.2.1  2008/02/18 22:01:32  Steve
 * Initial revision (taken from Falken project, originally from Bob project).
 *
 * Revision 1.1  2007/12/31 18:24:11  Steve
 * *** empty log message ***
 *
 * Original Revision 2005/11/29
 *
 */
