/*
 * AbstractFileComparator.java
 * Part of the B'am library - a collection of general-purpose utility classes.
 * 
 * Copyright (C)2006 Stephen Battey
 * Contact: resource@lucidviews.net
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

package net.lucidviews.util.io;

import java.io.File;


/**
 * An abstract base class for file comparators.
 * <br />
 * This class implements the <code>FileComparator</code> interface and provides
 * a default implementation of the <code>compare( Object, Object )</code>
 * method.
 * <br />
 * Sub-classes therefore just need to implement the
 * <code>compare( File, File )</code> method and the
 * <code>equals( Object )</code> method.
 * <br />
 * <br />
 * @author Stephen Battey
 * @version $Revision: 1.1.2.1 $
 * @since 1.0
 */
public abstract class AbstractFileComparator implements FileComparator
{
	
	/*
	 * Partial implementation of the Comparator interface
	 */
	
	/** {@inheritDoc} */
	public int compare( Object o1, Object o2 )
	{
		if (   (o1 != null)
		    && (!(o1 instanceof File))  )
			throw new ClassCastException( "Cannot use FileComparator " + this.getClass().getName() + " to compare object of type " + o1.getClass().getName() );
		
		if (   (o2 != null)
		    && (!(o2 instanceof File))  )
			throw new ClassCastException( "Cannot use FileComparator " + this.getClass().getName() + " to compare object of type " + o2.getClass().getName() );
		
		// otherwise both objects are either Files or null references
		return compare( (File)o1, (File)o2 );
	}
	
}


/*
 * Change History
 *
 * $Log: AbstractFileComparator.java,v $
 * Revision 1.1.2.1  2008/01/19 16:33:45  Steve
 * Added a JavaDoc comment.
 *
 * Revision 1.1  2006/09/13 20:09:30  Steve
 * Initial revision.
 *
 */