/*
 * FileDateComparatorTest.java
 * Part of the B'am library - a collection of general-purpose utility classes.
 * 
 * Copyright (C)2006 Stephen Battey
 * Contact: resource@lucidviews.net
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

package net.lucidviews.util.io;

import junit.framework.TestCase;

import java.io.File;


/**
 * Test harness for the <code>FileDateComparator</code> class.
 * <br />
 * <br />
 * @author Stephen Battey
 * @version $Revision: 1.1 $
 * @since 1.0
 */
public class FileDateComparatorTest extends TestCase
{
	
	/*
	 * Local constants
	 */
	
	/** The folder where the test files are stored. */
	protected static final File TEST_FOLDER = new File( "./Test/Files/FileDateComparator" );
	
	
	/*
	 * Instance variables
	 */
	
	protected File _f1;
	protected File _f2;
	protected File _f3;
	protected File _f3prime;
	
	
	/*
	 * Static methods
	 */
	
	/**
	 * Runs the test in the command console.
	 * <br />
	 * @param args not used
	 */
	public static void main( String[] args )
	{
		junit.textui.TestRunner.run( FileDateComparatorTest.class );
	}
	
	
	/*
	 * Overridden methods of TestCase base class
	 */
	
	public void setUp() throws Exception
	{
		super.setUp();
		
		_f1 = new File( TEST_FOLDER, "f1.txt" );
		if (!_f1.exists())
			throw new Exception( "File f1.txt missing from test folder " + TEST_FOLDER.getAbsolutePath() + ". Please ensure a file with this name is created with timestamp before files f2, f3, f3_." );
		
		_f2 = new File( TEST_FOLDER, "f2.txt" );
		if (!_f2.exists())
			throw new Exception( "File f2.txt missing from test folder " + TEST_FOLDER.getAbsolutePath() + ". Please ensure a file with this name is created with timestamp after f1 and before files f3, f3_." );
		
		_f3 = new File( TEST_FOLDER, "f3.txt" );
		if (!_f3.exists())
			throw new Exception( "File f3.txt missing from test folder " + TEST_FOLDER.getAbsolutePath() + ". Please ensure a file with this name is created with timestamp after f1 and f2 and the same time as f3_." );
		
		_f3prime = new File( TEST_FOLDER, "f3_.txt" );
		if (!_f3prime.exists())
			throw new Exception( "File f3_.txt missing from test folder " + TEST_FOLDER.getAbsolutePath() + ". Please ensure a file with this name is created with timestamp after f1 and f2 and the same time as f3." );
	}
	
	
	/*
	 * Test cases
	 */
	
	public void testTimestampBefore()
	{
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f1, _f2 ) < 0 );
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f1, _f3 ) < 0 );
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f1, _f3prime ) < 0 );
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f2, _f3 ) < 0 );
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f2, _f3prime ) < 0 );
		
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f1, _f2 ) > 0 );
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f1, _f3 ) > 0 );
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f1, _f3prime ) > 0 );
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f2, _f3 ) > 0 );
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f2, _f3prime ) > 0 );
	}
	
	public void testTimestampAfter()
	{
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f2, _f1 ) > 0 );
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f3, _f1 ) > 0 );
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f3prime, _f1 ) > 0 );
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f3, _f2 ) > 0 );
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f3prime, _f2 ) > 0 );
		
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f2, _f1 ) < 0 );
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f3, _f1 ) < 0 );
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f3prime, _f1 ) < 0 );
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f3, _f2 ) < 0 );
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f3prime, _f2 ) < 0 );
	}
	
	public void testTimestampEqual()
	{
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f3prime, _f3 ) == 0 );
		assertTrue( FileDateComparator.CHRONOLOGICAL.compare( _f3, _f3prime ) == 0 );
		
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f3prime, _f3 ) == 0 );
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.compare( _f3, _f3prime ) == 0 );
	}
	
	public void testEquals()
	{
		assertTrue( FileDateComparator.CHRONOLOGICAL.equals( FileDateComparator.CHRONOLOGICAL ) );
		assertTrue( FileDateComparator.REVERSE_CHRONOLOGICAL.equals( FileDateComparator.REVERSE_CHRONOLOGICAL ) );
		assertFalse( FileDateComparator.CHRONOLOGICAL.equals( FileDateComparator.REVERSE_CHRONOLOGICAL ) );
		assertFalse( FileDateComparator.REVERSE_CHRONOLOGICAL.equals( FileDateComparator.CHRONOLOGICAL ) );
	}
	
}


/*
 * Change History
 *
 * $Log: FileDateComparatorTest.java,v $
 * Revision 1.1  2006/09/13 20:09:30  Steve
 * Initial revision.
 *
 */