/*
 * FilePathsTest.java
 * Part of the B'am library - a collection of general-purpose utility classes.
 * 
 * Copyright (C)2006 Stephen Battey
 * Contact: resource@lucidviews.net
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.lucidviews.util.io;

import java.util.HashMap;
import java.util.Map;

import junit.framework.TestCase;


/**
 * Test harness for the <code>FilePaths</code> class.
 * <br />
 * <br />
 * @author Stephen Battey
 * @version $Revision: 1.1.2.1 $
 * @since 1.3
 */
public class FilePathsTest extends TestCase
{
	
	/*
	 * Static methods
	 */
	
	/**
	 * Runs the test in the command console.
	 * <br />
	 * @param args not used
	 */
	public static void main( String[] args )
	{
		junit.textui.TestRunner.run( FilePathsTest.class );
	}
	
	
	/*
	 * Test cases
	 */
	
	/**
	 * Verify the validateFileName method resolves special characters.
	 */
	public static void testValidateFileName()
	{
		final Map<Character,Character> replacementChars = new HashMap<Character,Character>();
		replacementChars.put( ':', 'c' );
		replacementChars.put( '*', 'a' );
		replacementChars.put( '|', 'b' );
		// The three characters  ? < >  are deliberately excluded from the replacement mapping.
		
		String validatedFileName;
		
		validatedFileName = FilePaths.validateFileName( "some.txt", replacementChars );
		assertEquals( "testValidateFileName 1", "some.txt", validatedFileName );
		
		validatedFileName = FilePaths.validateFileName( "so:me:.txt", replacementChars );
		assertEquals( "testValidateFileName 2", "socmec.txt", validatedFileName );
		
		validatedFileName = FilePaths.validateFileName( "so*me|.txt", replacementChars );
		assertEquals( "testValidateFileName 3", "soameb.txt", validatedFileName );
		
		validatedFileName = FilePaths.validateFileName( "so?me?.txt", replacementChars );
		assertEquals( "testValidateFileName 4", "some.txt", validatedFileName );
		
		validatedFileName = FilePaths.validateFileName( "so<me>.txt", replacementChars );
		assertEquals( "testValidateFileName 5", "some.txt", validatedFileName );
		
		validatedFileName = FilePaths.validateFileName( ":*?s>o<<**|me>|.txt", replacementChars );
		assertEquals( "testValidateFileName 6", "casoaabmeb.txt", validatedFileName );
	}
	
}


/*
 * Change History
 *
 * $Log: FilePathsTest.java,v $
 * Revision 1.1.2.1  2008/02/24 20:18:33  Steve
 * Initial revision.
 *
 */